Introduction
============

Plone support for MLS Listings.


Mostly Harmless
---------------

.. image:: https://travis-ci.org/propertyshelf/plone.mls.listing.png?branch=master
    :target: http://travis-ci.org/propertyshelf/plone.mls.listing
    :alt: Travis CI status

.. image:: https://coveralls.io/repos/propertyshelf/plone.mls.listing/badge.png?branch=master
    :target: https://coveralls.io/r/propertyshelf/plone.mls.listing?branch=master
    :alt: Coveralls status

.. image:: https://badge.fury.io/py/plone.mls.listing.png
    :target: http://badge.fury.io/py/plone.mls.listing
    :alt: Fury Python

.. image:: https://badge.fury.io/gh/propertyshelf%2Fplone.mls.listing.png
    :target: http://badge.fury.io/gh/propertyshelf%2Fplone.mls.listing
    :alt: Fury Github

.. image:: https://pypip.in/d/plone.mls.listing/badge.png
    :target: https://pypi.python.org/pypi/plone.mls.listing/
    :alt: Downloads

.. image:: https://pypip.in/v/plone.mls.listing/badge.png
    :target: https://pypi.python.org/pypi/plone.mls.listing/
    :alt: Latest Version

.. image:: https://pypip.in/wheel/plone.mls.listing/badge.png
    :target: https://pypi.python.org/pypi/plone.mls.listing/
    :alt: Wheel Status

.. image:: https://pypip.in/egg/plone.mls.listing/badge.png
    :target: https://pypi.python.org/pypi/plone.mls.listing/
    :alt: Egg Status

.. image:: https://pypip.in/license/plone.mls.listing/badge.png
    :target: https://pypi.python.org/pypi/plone.mls.listing/
    :alt: License
